@@ -6,8 +6,11 @@
  | bin/cleandb.sh                                                        |
  |                                                                       |
  | This file is part of the Roundcube Webmail client                     |
- | Copyright (C) 2010, Roundcube Dev. - Switzerland                      |
- | Licensed under the GNU GPL                                            |
+ | Copyright (C) 2010, The Roundcube Dev Team                            |
+ |                                                                       |
+ | Licensed under the GNU General Public License version 3 or            |
+ | any later version with exceptions for skins & plugins.                |
+ | See the README file for a full license statement.                     |
  |                                                                       |
  | PURPOSE:                                                              |
  |   Finally remove all db records marked as deleted some time ago       |
@@ -16,16 +19,13 @@
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
 
- $Id: cleandb.sh 3989 2010-09-25 13:03:53Z alec $
+ $Id$
 
 */
 
-if (php_sapi_name() != 'cli') {
-    die('Not on the "shell" (php-cli).');
-}
-
 define('INSTALL_PATH', realpath(dirname(__FILE__) . '/..') . '/' );
-require INSTALL_PATH.'program/include/iniset.php';
+
+require INSTALL_PATH.'program/include/clisetup.php';
 
 // mapping for table name => primary key
 $primary_keys = array(
@@ -36,9 +36,10 @@ $primary_keys = array(
 // connect to DB
 $RCMAIL = rcmail::get_instance();
 $db = $RCMAIL->get_dbh();
+$db->db_connect('w');
 
-if (!$db->is_connected() || $db->is_error)
-    die("No DB connection");
+if (!$db->is_connected() || $db->is_error())
+    die("No DB connection\n");
 
 if (!empty($_SERVER['argv'][1]))
     $days = intval($_SERVER['argv'][1]);
