@@ -5,8 +5,11 @@
  | program/include/rcube_result_set.php                                  |
  |                                                                       |
  | This file is part of the Roundcube Webmail client                     |
- | Copyright (C) 2006-2010, Roundcube Dev. - Switzerland                 |
- | Licensed under the GNU GPL                                            |
+ | Copyright (C) 2006-2011, The Roundcube Dev Team                       |
+ |                                                                       |
+ | Licensed under the GNU General Public License version 3 or            |
+ | any later version with exceptions for skins & plugins.                |
+ | See the README file for a full license statement.                     |
  |                                                                       |
  | PURPOSE:                                                              |
  |   Class representing an address directory result set                  |
@@ -15,7 +18,7 @@
  | Author: Thomas Bruederli <roundcube@gmail.com>                        |
  +-----------------------------------------------------------------------+
 
- $Id: rcube_result_set.php 3989 2010-09-25 13:03:53Z alec $
+ $Id$
 
 */
 
@@ -31,6 +34,7 @@ class rcube_result_set
     var $count = 0;
     var $first = 0;
     var $current = 0;
+    var $searchonly = false;
     var $records = array();
 
 
@@ -44,27 +48,27 @@ class rcube_result_set
     {
         $this->records[] = $rec;
     }
-  
+
     function iterate()
     {
         return $this->records[$this->current++];
     }
-  
+
     function first()
     {
         $this->current = 0;
         return $this->records[$this->current++];
     }
-  
+
     // alias for iterate()
     function next()
     {
         return $this->iterate();
     }
-  
+
     function seek($i)
     {
         $this->current = $i;
     }
-  
+
 }
